/*
 * Copyright (C) 2003 Russell Miller <rmiller@duskglow.com>
 */

#include "klicker.h"
#include "klickerview.h"
#include "pref.h"

#include <kglobal.h>
#include <klocale.h>
#include <kiconloader.h>
#include <kdeversion.h>
#include <kmenubar.h>
#include <kstatusbar.h>
#include <kkeydialog.h>
#include <kaccel.h>
#include <kconfig.h>

#include <kedittoolbar.h>
#include <kuniqueapplication.h>

#include <kstdaccel.h>
#include <kaction.h>
#include <kstdaction.h>

klicker::klicker()
    : KMainWindow( 0, "klicker" , WStyle_ContextHelp | WDestructiveClose),
      m_view(new klickerView(this))
{

    // tell the KMainWindow that this is indeed the main widget
    setCentralWidget(m_view);

    // then, setup our actions
    setupActions();

    // and a status bar
    statusBar()->show();
    // apply the saved mainwindow settings, if any, and ask the mainwindow
    // to automatically save settings if changed: window size, toolbar
    // position, icon size, etc.
    setAutoSaveSettings();

    // allow the view to change the statusbar and caption
    connect(m_view, SIGNAL(signalChangeStatusbar(const QString&)),
            this,   SLOT(changeStatusbar(const QString&)));
    connect(m_view, SIGNAL(signalChangeCaption(const QString&)),
            this,   SLOT(changeCaption(const QString&)));
    connect(m_view, SIGNAL(signalSoundOn()),
	    this,   SLOT(soundOnReceived()));
    connect(m_view, SIGNAL(signalSoundOff()),
	    this,   SLOT(soundOffReceived()));
    connect(m_view, SIGNAL(signalStart()),
	    this,   SLOT(metronomeOnReceived()));
    connect(m_view, SIGNAL(signalStop()),
	    this,   SLOT(metronomeOffReceived()));

}

klicker::~klicker()
{
}

void klicker::setupActions()
{

    KStdAction::quit(kapp, SLOT(quit()), actionCollection());
#ifdef KLICKER_KDE_3_2_0
    createStandardStatusBarAction();
    setStandardToolBarMenuEnabled(true);
#else
    m_statusbarAction = KStdAction::showStatusbar(this, SLOT(optionsShowStatusbar()), actionCollection());
    m_toolbarAction = KStdAction::showToolbar(this, SLOT(optionsShowToolbar()), actionCollection());
#endif

    KStdAction::keyBindings(this, SLOT(optionsConfigureKeys()), actionCollection());

    startAction = new KToggleAction(i18n("Metronome On"), 0,
                                  this, SLOT(toggle()),
                                  actionCollection(), "start_action");
    soundAction = new KToggleAction(i18n("Use Sound"), 0,
		    		  this, SLOT(sound()),
				  actionCollection(), "sound_action");
    easterAction = new KToggleAction(i18n("Easter Egg"), 0,
		    		  this, SLOT(easterEgg()),
				  actionCollection(), "easter_action");

    soundAction->setChecked(false);

    startAction->setIcon("player_play");
    soundAction->setIcon("music_quarternote");
    easterAction->setIcon("knewstuff");

    startAction->setWhatsThis("Start and stop the metronome");
    soundAction->setWhatsThis("Turn on and off the sound");
		    createGUI();
    easterAction->setWhatsThis("I've never been good at the cloak and dagger stuff...");
}

void klicker::saveProperties(KConfig *)
{

}

void klicker::readProperties(KConfig *)
{

}

void klicker::optionsShowToolbar()
{
    // this is all very cut and paste code for showing/hiding the
    // toolbar
    if (m_toolbarAction->isChecked())
        toolBar()->show();
    else
        toolBar()->hide();
}

void klicker::optionsShowStatusbar()
{
    // this is all very cut and paste code for showing/hiding the
    // statusbar
    if (m_statusbarAction->isChecked())
        statusBar()->show();
    else
        statusBar()->hide();
}

void klicker::optionsConfigureKeys()
{
    KKeyDialog::configure(actionCollection(), this);
}

void klicker::optionsConfigureToolbars()
{
    // use the standard toolbar editor
#if defined(KDE_MAKE_VERSION)
# if KDE_VERSION >= KDE_MAKE_VERSION(3,1,0)
    saveMainWindowSettings(KGlobal::config(), autoSaveGroup());
# else
    saveMainWindowSettings(KGlobal::config());
# endif
#else
    saveMainWindowSettings(KGlobal::config());
#endif
}

void klicker::newToolbarConfig()
{
    // this slot is called when user clicks "Ok" or "Apply" in the toolbar editor.
    // recreate our GUI, and re-apply the settings (e.g. "text under icons", etc.)
    createGUI();

#if defined(KDE_MAKE_VERSION)
# if KDE_VERSION >= KDE_MAKE_VERSION(3,1,0)
    applyMainWindowSettings(KGlobal::config(), autoSaveGroup());
# else
    applyMainWindowSettings(KGlobal::config());
# endif
#else
    applyMainWindowSettings(KGlobal::config());
#endif
}

void klicker::changeStatusbar(const QString& text)
{
    // display the text on the statusbar
    statusBar()->message(text);
}

void klicker::changeCaption(const QString& text)
{
    // display the text on the caption
    setCaption(text);
}

void klicker::toggle()
{
    if (startAction->isChecked() == false) {
	m_view->stop();
    } else {
        m_view->start();
    }
}

void klicker::soundOnReceived() {

	soundAction->setChecked(true);

}

void klicker::soundOffReceived() {

	soundAction->setChecked(false);

}

void klicker::metronomeOnReceived() {

	startAction->setChecked(true);

}

void klicker::metronomeOffReceived() {

	startAction->setChecked(false);

}

void klicker::sound() {
	if (soundAction->isChecked() == false) {
		m_view->soundOff();
	} else {
		m_view->soundOn();
	}
}

void klicker::easterEgg() {
	if (easterAction->isChecked() == false) {
		m_view->easterOff();
	} else {
		m_view->easterOn();
	}
}

void klicker::closeEvent(QCloseEvent *) {

	KUniqueApplication::kApplication()->quit();

}
#include "klicker.moc"
