/*
 * Copyright (C) 2003 Russell Miller <rmiller@duskglow.com>
 */

/***************************************************************************
 *                                                                         *
 *  This program is free software; you can redistribute it and/or modify  *
 *  it under the terms of the GNU General Public License as published by  *
 *  the Free Software Foundation; either version 2 of the License, or     *
 *  (at your option) any later version.                                   *
 *                                                                        *
 *****************************************************************************/

#ifndef _KLICKER_H_
#define _KLICKER_H_

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include <kapplication.h>
#include <kmainwindow.h>

#ifdef KDE_IS_VERSION
#if KDE_IS_VERSION(3,1,90)
#define KLICKER_KDE_3_2_0
//#else
#endif
#endif

class KToggleAction;
class klickerView;

/**
 * This class serves as the main window for klicker.  It handles the
 * menus, toolbars, and status bars.
 *
 * @short Main window class
 * @author $AUTHOR <$EMAIL>
 * @version $APP_VERSION
 */
class klicker : public KMainWindow
{
    Q_OBJECT
public:
    /**
     * Default Constructor
     */
    klicker();

    /**
     * Default Destructor
     */
    virtual ~klicker();

protected:
    /**
     * Overridden virtuals for Qt drag 'n drop (XDND)
     */

protected:
    /**
     * This function is called when it is time for the app to save its
     * properties for session management purposes.
     */
    void saveProperties(KConfig *);

    /**
     * This function is called when this app is restored.  The KConfig
     * object points to the session management config file that was saved
     * with @ref saveProperties
     */
    void readProperties(KConfig *);


private slots:
    void optionsShowToolbar();
    void optionsShowStatusbar();
    void optionsConfigureKeys();
    void optionsConfigureToolbars();
    void newToolbarConfig();

    void changeStatusbar(const QString& text);
    void changeCaption(const QString& text);

    void toggle();

    void sound();

    void easterEgg();

    void soundOnReceived();
    void soundOffReceived();
    void metronomeOnReceived();
    void metronomeOffReceived();

    void closeEvent(QCloseEvent *);
private:
    void setupAccel();
    void setupActions();

private:
    klickerView *m_view;

    KToggleAction *m_toolbarAction;
    KToggleAction *m_statusbarAction;

    KToggleAction *startAction;
    KToggleAction *soundAction;
    KToggleAction *easterAction;


};

#endif // _KLICKER_H_
