/*
 * Copyright (C) 2003 Russell Miller <rmiller@duskglow.com>
 */

#include "klickerview.h"
#include "metronomewidget.h"

#include <qlayout.h>

#include <kmessagebox.h>
#include <klocale.h>
#include <kuniqueapplication.h>
#include <dcopclient.h>

klickerView::klickerView(QWidget *parent)
    : QWidget(parent),
      DCOPObject("klicker")
{
    // setup our layout manager to automatically add our widgets
    QHBoxLayout *top_layout = new QHBoxLayout(this);
    top_layout->setAutoAdd(true);

    m_view = new metronomeWidget(this);

    connect(this, SIGNAL(signalStart()), m_view, SLOT(start()));
    connect(this, SIGNAL(signalStop()), m_view, SLOT(stop()));
    connect(this, SIGNAL(signalInterval(int)), m_view,
    	SLOT(changeInterval(int)) );
    connect(this, SIGNAL(signalSoundOn()), m_view, SLOT(enableSound()));
    connect(this, SIGNAL(signalSoundOff()), m_view, SLOT(disableSound()));
    connect(this, SIGNAL(signalEasterOn()), m_view, SLOT(enableEaster()));
    connect(this, SIGNAL(signalEasterOff()), m_view, SLOT(disableEaster()));
    connect(m_view, SIGNAL(signalChangeStatusBar(const QString&)), this,
	SLOT(changeStatusBar(const QString&)));

    m_view->show();
}

klickerView::~klickerView()
{
}

void klickerView::slotSetTitle(const QString& title)
{
    emit signalChangeCaption(title);
}

void klickerView::start()
{
    emit signalStart();
}

void klickerView::stop()
{
    emit signalStop();
}

void klickerView::changeInterval(int i)
{
    emit signalInterval(i);
}

void klickerView::soundOn()
{
	emit signalSoundOn();
}

void klickerView::soundOff()
{
	emit signalSoundOff();
}

void klickerView::easterOn()
{
	emit signalEasterOn();
}

void klickerView::easterOff()
{
	emit signalEasterOff();
}

int klickerView::newInstance()
{
	KUniqueApplication::dcopClient()->setPriorityCall(false); // Allow other dcop calls
        return 0;
}

void klickerView::changeStatusBar(const QString &text)
{
	emit signalChangeStatusbar(text);
}

void klickerView::quit()
{
	KUniqueApplication::kApplication()->quit();
}

#include "klickerview.moc"
