/*
 * Copyright (C) 2003 Russell Miller <rmiller@duskglow.com>
 */

/***************************************************************************
 *                                                                         *
 *  This program is free software; you can redistribute it and/or modify  *
 *  it under the terms of the GNU General Public License as published by  *
 *  the Free Software Foundation; either version 2 of the License, or     *
 *  (at your option) any later version.                                   *
 *                                                                        *
 *****************************************************************************/

#ifndef _KLICKERVIEW_H_
#define _KLICKERVIEW_H_

#include <qwidget.h>
#include <klickeriface.h>

class metronomeWidget;
/**
 * This is the main view class for klicker.  Most of the non-menu,
 * non-toolbar, and non-statusbar (e.g., non frame) GUI code should go
 * here.
 *
 * This klicker uses an HTML component as an example.
 *
 * @short Main view
 * @author Russell Miller <rmiller@duskglow.com>
 * @version 0.1
 */
class klickerView : public QWidget, public klickerIface
{
    Q_OBJECT
public:
	/**
	 * Default constructor
	 */
    klickerView(QWidget *parent);

	/**
	 * Destructor
	 */
    virtual ~klickerView();

    int newInstance();
    void quit();

signals:
    /**
     * Use this signal to change the content of the statusbar
     */
    void signalChangeStatusbar(const QString& text);

    /**
     * Use this signal to change the content of the caption
     */
    void signalChangeCaption(const QString& text);
    void signalStart();
    void signalStop();
    void signalInterval(int);
    void signalSoundOn();
    void signalSoundOff();
    void signalMetronomeOn();
    void signalMetronomeOff();
    void signalEasterOn();
    void signalEasterOff();

private slots:
    void slotSetTitle(const QString& title);
    void changeStatusBar(const QString&);

public slots:
    void start();
    void stop();
    void changeInterval(int);
    void soundOn();
    void soundOff();
    void easterOn();
    void easterOff();

private:
    metronomeWidget *m_view;
};

#endif // _KLICKERVIEW_H_
