/****************************************************************************
** ui.h extension file, included from the uic-generated form implementation.
**
** If you wish to add, delete or rename functions or slots use
** Qt Designer which will update this file, preserving your code. Create an
** init() function in place of a constructor, and a destroy() function in
** place of a destructor.
*****************************************************************************/

/***************************************************************************
 *                                                                         *
 *  This program is free software; you can redistribute it and/or modify  *
 *  it under the terms of the GNU General Public License as published by  *
 *  the Free Software Foundation; either version 2 of the License, or     *
 *  (at your option) any later version.                                   *
 *                                                                        *
 *****************************************************************************/

#ifndef METRONOME_UI_H
#define METRONOME_UI_H

#include <kpushbutton.h>
#include <qtimer.h>
#include <kmessagebox.h>
#include <kstatusbar.h>
#include <kapplication.h>

#include "metronomewidget.h"

int meter = 0;
int beat = 0;
int sound = 0;
int easter = 0;

QTimer *t;
QTimer *deactTimer;

void metronomeWidget::init() {
    int interval;
    t = new QTimer(this);
    deactTimer = new QTimer(this);

    // define the frequencies for the two beeps.
    frequency1 = 880.0;
    frequency2 = 440.0;

    server = ka.server();

    // should it just force sound to off?
    if (server.isNull()) {
	    KMessageBox::sorry(this, "Can't connect to sound server",
			    "Sound server unavailable");
	    exit(0);
    }


    connect(t, SIGNAL(timeout()), this, SLOT(timeout()));
    connect(deactTimer, SIGNAL(timeout()), this, SLOT(beepOff()));

    interval = getInterval(tempoDial->value());
    if (meter == 0) {
	dupleLED->on();
    } else if (meter == 1) {
	tripleLED->on();
    } else {
	fourLED->on();
    }

    // Create the synth objects.  must do it from the server for it to work.
    play = Arts::DynamicCast(server.createObject("Arts::Synth_AMAN_PLAY"));
    freq = Arts::DynamicCast(server.createObject("Arts::Synth_FREQUENCY"));
    sin = Arts::DynamicCast(server.createObject("Arts::Synth_WAVE_SIN"));
    adsr = Arts::DynamicCast(server.createObject("Arts::Synth_ENVELOPE_ADSR"));

    // initializing the play object is required.
    play.title("klicker");
    play.autoRestoreID("klicker");
    
    Arts::setValue(freq, frequency2);
    // these values were carefully chosen.  If you MUST alter them, make sure
    // that they total around 100ms, or you will have sound problems.
    Arts::setValue(adsr, "attack", 0.030);
    Arts::setValue(adsr, "decay", 0.030);
    Arts::setValue(adsr, "sustain", 0.010);
    Arts::setValue(adsr, "release", 0.030);
    Arts::setValue(adsr, "active", 0.0);
    Arts::connect(freq, sin);
    Arts::connect(sin, adsr, "invalue");
    Arts::connect(adsr, "outvalue", play, "left");
    Arts::connect(adsr, "outvalue", play, "right");

    // start the objects.  This is, of course, different from actually
    // generating the sound - that is done by bringing adsr.active high.
    freq.start();
    sin.start();
    adsr.start();
    play.start();

    // And, of course, set the lcd to a sane value.
    tempoLCD->display(tempoDial->value());

}

void metronomeWidget::destroy() {

	freq.stop();
	sin.stop();
	adsr.stop();
	play.stop();

	Arts::disconnect(adsr, "outvalue", play, "right");
	Arts::disconnect(adsr, "outvalue", play, "left");
	Arts::disconnect(freq, sin);
	Arts::disconnect(sin, adsr, "invalue");

	server = Arts::SoundServerV2::null();

}

void metronomeWidget::beepOff() {

	// the beep is turned off by setting active low.
	Arts::setValue(adsr, "active", 0.0);
	emit signalChangeStatusBar((const QString &)QString::QString(""));
}

void metronomeWidget::enableSound() {

	sound = 1;
}

void metronomeWidget::disableSound() {

	sound = 0;
	Arts::setValue(adsr, "active", 0.0);

}

void metronomeWidget::enableEaster() {

	easter = 1;
}

void metronomeWidget::disableEaster() {

	easter = 0;

}

void metronomeWidget::dupleButtonClicked()
{
    meter = 0;
}


void metronomeWidget::tripleButtonClicked( )
{
    meter = 1;
}


void metronomeWidget::fourButtonClicked( )
{
    meter = 2;
}

int metronomeWidget::getInterval(int i)
{
    int interval;

    interval = 60000;	// number of milliseconds in a minute.
    interval /= i;		// beats per minute, but expressed in milliseconds
    return interval;

}

void metronomeWidget::changeInterval(int i)
{
    bool a;
    int interval;
    interval = getInterval(i);
    a = t->isActive();
    t->changeInterval(interval);
    if (!a) {
	t->stop();
    }
    tempoLCD->display(i);
}

void metronomeWidget::timeout()
{
    beat++;
    if (beat >= meter + 2) {
	beat = 0;
    }
    if (beat == 0) {
	Arts::setValue(freq, frequency1);
	outLED1->on();
	outLED2->off();
	outLED3->off();
	outLED4->off();
    } else if (beat == 1) {
	Arts::setValue(freq, frequency2);
	outLED1->off();
	outLED2->on();
	outLED3->off();
	outLED4->off();
    } else if (beat == 2) {
	Arts::setValue(freq, frequency2);
	outLED1->off();
	outLED2->off();
	outLED3->on();
	outLED4->off();
    } else if (beat == 3) {
	Arts::setValue(freq, frequency2);
	outLED1->off();
	outLED2->off();
	outLED3->off();
	outLED4->on();
    }
    if (sound == 1) {

	    Arts::setValue(adsr, "active", 1.0);

	    // this is connected elsewhere to beepOff.
	    // don't set it for less than 100ms, or you risk not having the
	    // sound show up at all.
	    deactTimer->start(100, true);
    }
    if (easter == 1) {
	    if (beat == 1) {
	emit signalChangeStatusBar((const QString &)QString::QString("Boop"));
	    } else {
	emit signalChangeStatusBar((const QString &)QString::QString("Beep"));
	    }
    }
}

void metronomeWidget::start()
{
    t->start(getInterval(tempoDial->value()), false);
    powerLED->on();
}

void metronomeWidget::stop()
{
    t->stop();
    beat = 0;
    powerLED->off();
    outLED1->off();
    outLED2->off();
    outLED3->off();
    outLED4->off();
}

#endif
